@@ -587,7 +587,7 @@ class OrbitPlotter:
         else:
             final_phase_position = final_phase.r
 
-        if not len(maneuver_phases):
+        if len(maneuver_phases) == 0:
             # For single-impulse maneuver only draw the impulse marker
             impulse_label = f"Impulse - {label}"
             impulse_lines = (
@@ -602,9 +602,6 @@ class OrbitPlotter:
                     )
                 ],
             )
-            # XXX this function is only used in tests and does not use
-            #    a return value
-            # XXX todo is that correct: return [(impulse_label, impulse_lines)]
             return
 
         # Declare for holding (label, lines) for each impulse and trajectory
