@@ -432,7 +432,7 @@ def test_sample_numpoints():
 
 
 def test_sample_big_orbits():
-    # See https://github.com/boinor/boinor/issues/265
+    # See https://github.com/poliastro/poliastro/issues/265
     ss = Orbit.from_vectors(
         Sun,
         [-9_018_878.6, -94_116_055, 22_619_059] * u.km,
@@ -1288,7 +1288,7 @@ def test_time_to_anomaly(expected_nu):
     # In some corner cases the resulting anomaly goes out of range,
     # and rather than trying to fix it right now
     # we will wait until we remove the round tripping,
-    # see https://github.com/boinor/boinor/issues/921
+    # see https://github.com/poliastro/poliastro/issues/921
     # FIXME: Add test that verifies that `orbit.nu` is always within range
     assert_quantity_allclose(
         iss_propagated.nu, expected_nu, atol=1e-12 * u.rad
@@ -1297,7 +1297,7 @@ def test_time_to_anomaly(expected_nu):
 
 @pytest.mark.xfail
 def test_can_set_iss_attractor_to_earth():
-    # See https://github.com/boinor/boinor/issues/798
+    # See https://github.com/poliastro/poliastro/issues/798
     epoch = Time("2019-11-10 12:00:00")
     ephem = Ephem.from_horizons(
         "International Space Station",
@@ -1326,7 +1326,7 @@ def test_issue_916(mock_query):
 
 
 def test_near_parabolic_M_does_not_hang(near_parabolic):
-    # See https://github.com/boinor/boinor/issues/907
+    # See https://github.com/poliastro/poliastro/issues/907
     expected_nu = -168.65 * u.deg
     orb = near_parabolic.propagate_to_anomaly(expected_nu)
 
@@ -1344,7 +1344,7 @@ def test_propagation_near_parabolic_orbits_zero_seconds_gives_same_anomaly(
 
 
 def test_propagation_near_parabolic_orbits_does_not_hang(near_parabolic):
-    # See https://github.com/boinor/boinor/issues/475
+    # See https://github.com/poliastro/poliastro/issues/475
     orb_final = near_parabolic.propagate(near_parabolic.period)
 
     # Smoke test
@@ -1443,29 +1443,24 @@ def test_orbit_object():
 
     # TODO due to pylint:abstract-method, those functions need to be implemented
     #      for to_equinoctial() before being tested
-    # with pytest.raises(NotImplementedError, match=""):
-    #    f = orbit.f
-    #    assert f == f  # just needed to not tweak away some code
-    #
-    #    with pytest.raises(NotImplementedError, match=""):
-    #        g = orbit.g
-    #        assert g == g  # just needed to not tweak away some code
-    #
-    #    with pytest.raises(NotImplementedError, match=""):
-    #        h = orbit.h
-    #        assert h == h  # just needed to not tweak away some code
-    #
-    #    with pytest.raises(NotImplementedError, match=""):
-    #        k = orbit.k
-    #        assert k == k  # just needed to not tweak away some code
+
+    expected_f = 2573.6351895322036
+    assert_quantity_allclose(expected_f, orbit.f)
+
+    expected_g = 1944.31824891431 * u.rad
+    assert_quantity_allclose(expected_g, orbit.g)
+
+    expected_h = 0.6969652274284632 * u.rad
+    assert_quantity_allclose(expected_h, orbit.h)
+
+    expected_k = 1.9040322142087245 * u.rad
+    assert_quantity_allclose(expected_k, orbit.k)
 
     expected_L = 6.494977004500326 * u.rad
-    L = orbit.L
-    assert_quantity_allclose(L, expected_L)
+    assert_quantity_allclose(expected_L, orbit.L)
 
     expected_n = 78.73646041349888 * u.rad / u.s
-    n = orbit.n
-    assert_quantity_allclose(n, expected_n)
+    assert_quantity_allclose(expected_n, orbit.n)
 
     # new Orbit object
     r = [1e09, -4e09, -1e09] * u.km
@@ -1517,6 +1512,48 @@ def test_orbit_object():
     ):
         oc.propagate(1.0 * u.h, method=TestDummyPropagatorElliptic())
 
+    # next test with data from Vallado, example 2.6
+    # check whether from_classical() creates MEE values
+    attractor = Earth
+    p = 11_067.790 * u.km
+    ecc = 0.83285 * u.one
+    inc = 87.87 * u.deg
+    raan = 227.89 * u.deg
+    argp = 53.38 * u.deg
+    nu = 92.335 * u.deg
+    expected_f = 0.1 * u.rad
+    expected_g = 0.1 * u.rad
+    expected_h = 0.1 * u.rad
+    expected_k = 0.1 * u.rad
+
+    orbit = Orbit.from_classical(
+        attractor=attractor,
+        a=p / (1 - ecc**2),
+        ecc=ecc,
+        inc=inc,
+        raan=raan,
+        argp=argp,
+        nu=nu,
+    )
+
+    expected_f = 0.162766
+    assert_quantity_allclose(expected_f, orbit.f, rtol=1e-06)
+
+    expected_g = -0.81679 * u.rad
+    assert_quantity_allclose(expected_g, orbit.g, rtol=1e-06)
+
+    expected_h = -0.64608 * u.rad
+    assert_quantity_allclose(expected_h, orbit.h, rtol=1e-06)
+
+    expected_k = -0.71478 * u.rad
+    assert_quantity_allclose(expected_k, orbit.k, rtol=1e-06)
+
+    expected_L = 6.520637 * u.rad
+    assert_quantity_allclose(expected_L, orbit.L, rtol=1e-06)
+
+    expected_n = 9.194487e-05 * u.rad / u.s
+    assert_quantity_allclose(expected_n, orbit.n, rtol=1e-06)
+
 
 # todo: test does not work due to check in other function
 #    oc=Orbit.from_classical(
